pub struct AdaptiveOptionsBuilder { /* private fields */ }Expand description
Builder for AdaptiveOptions.
Implementations
Sourceimpl AdaptiveOptionsBuilder
impl AdaptiveOptionsBuilder
Sourcepub fn minstep<VALUE: Into<Minstep>>(&mut self, value: VALUE) -> &mut Self
pub fn minstep<VALUE: Into<Minstep>>(&mut self, value: VALUE) -> &mut Self
Minimal integration step.
Sourcepub fn maxstep<VALUE: Into<Maxstep>>(&mut self, value: VALUE) -> &mut Self
pub fn maxstep<VALUE: Into<Maxstep>>(&mut self, value: VALUE) -> &mut Self
Maximal integration step.
Sourcepub fn initstep<VALUE: Into<Initstep>>(&mut self, value: VALUE) -> &mut Self
pub fn initstep<VALUE: Into<Initstep>>(&mut self, value: VALUE) -> &mut Self
Initial integration step.
Sourcepub fn points<VALUE: Into<Points>>(&mut self, value: VALUE) -> &mut Self
pub fn points<VALUE: Into<Points>>(&mut self, value: VALUE) -> &mut Self
Defaults to Points::All output is given for each value in tspan
as well as for each intermediate point the solver used.
Sourcepub fn reltol<VALUE: Into<Reltol>>(&mut self, value: VALUE) -> &mut Self
pub fn reltol<VALUE: Into<Reltol>>(&mut self, value: VALUE) -> &mut Self
An integration step is accepted if E <= reltol*abs(y)
defaults to 1e-5
Sourcepub fn abstol<VALUE: Into<Abstol>>(&mut self, value: VALUE) -> &mut Self
pub fn abstol<VALUE: Into<Abstol>>(&mut self, value: VALUE) -> &mut Self
An integration step is accepted if E <= abstol
defaults to 1e-8
Sourcepub fn norm<VALUE: Into<Norm>>(&mut self, value: VALUE) -> &mut Self
pub fn norm<VALUE: Into<Norm>>(&mut self, value: VALUE) -> &mut Self
User-supplied norm for determining the error.
Sourcepub fn step_timeout<VALUE: Into<StepTimeout>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn step_timeout<VALUE: Into<StepTimeout>>( &mut self, value: VALUE, ) -> &mut Self
User defined timeout after which step reduction should not increase step for timeout controlled steps.